@@ -7,7 +7,10 @@ Performance and quality analytics on Hive Posts.
 
 """
 
-__version__ = "1.3.9"
+__version__ = "1.3.11"
 from .scrutineer import Scrutineer
+from .scrutineer import get_keywords
+from .scrutineer import get_bigrams
+
 
 __all__ = ["scrutineer"]
